# -*- coding: utf-8 -*-
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <https://www.gnu.org/licenses/>.

"""
Created on Sat May 17 16:23:45 2025
Author: josemariacruzlorite@gmail.com
"""

BDNS_API_BASE_URL = "https://www.infosubvenciones.es/bdnstrans/api"
BDNS_API_ENDPOINT_CONVOCATORIAS_BUSQUEDA = f"{BDNS_API_BASE_URL}/convocatorias/busqueda"
BDNS_API_ENDPOINT_CONVOCATORIAS_ULTIMAS = f"{BDNS_API_BASE_URL}/convocatorias/ultimas"
BDNS_API_ENDPOINT_CONVOCATORIAS = f"{BDNS_API_BASE_URL}/convocatorias"
BDNS_API_ENDPOINT_CONVOCATORIAS_DOCUMENTOS = (
    f"{BDNS_API_BASE_URL}/convocatorias/documentos"
)
BDNS_API_ENDPOINT_CONVOCATORIAS_PDF = f"{BDNS_API_BASE_URL}/convocatorias/pdf"
BDNS_API_ENDPOINT_CONCESIONES_BUSQUEDA = f"{BDNS_API_BASE_URL}/concesiones/busqueda"
BDNS_API_ENDPOINT_AYUDASESTADO_BUSQUEDA = f"{BDNS_API_BASE_URL}/ayudasestado/busqueda"
BDNS_API_ENDPOINT_MINIMIS_BUSQUEDA = f"{BDNS_API_BASE_URL}/minimis/busqueda"
BDNS_API_ENDPOINT_GRANDES_BENEFICIARIOS_BUSQUEDA = (
    f"{BDNS_API_BASE_URL}/grandesbeneficiarios/busqueda"
)
BDNS_API_ENDPOINT_GRANDES_BENEFICIARIOS_ANIOS = (
    f"{BDNS_API_BASE_URL}/grandesbeneficiarios/anios"
)
BDNS_API_ENDPOINT_PARTIDOSPOLITICOS_BUSQUEDA = (
    f"{BDNS_API_BASE_URL}/partidospoliticos/busqueda"
)
BDNS_API_ENDPOINT_PLANESESTRATEGICOS_BUSQUEDA = (
    f"{BDNS_API_BASE_URL}/planesestrategicos/busqueda"
)
BDNS_API_ENDPOINT_PLANESESTRATEGICOS = f"{BDNS_API_BASE_URL}/planesestrategicos"
BDNS_API_ENDPOINT_PLANESESTRATEGICOS_DOCUMENTOS = (
    f"{BDNS_API_BASE_URL}/planesestrategicos/documentos"
)
BDNS_API_ENDPOINT_PLANESESTRATEGICOS_VIGENCIA = (
    f"{BDNS_API_BASE_URL}/planesestrategicos/vigencia"
)
BDNS_API_ENDPOINT_SANCIONES_BUSQUEDA = f"{BDNS_API_BASE_URL}/sanciones/busqueda"
BDNS_API_ENDPOINT_TERCEROS = f"{BDNS_API_BASE_URL}/terceros"
BDNS_API_ENDPOINT_REGIONES = f"{BDNS_API_BASE_URL}/regiones"
BDNS_API_ENDPOINT_FINALIDADES = f"{BDNS_API_BASE_URL}/finalidades"
BDNS_API_ENDPOINT_TIPOS_BENEFICIARIOS = f"{BDNS_API_BASE_URL}/beneficiarios"
BDNS_API_ENDPOINT_INSTRUMENTOS = f"{BDNS_API_BASE_URL}/instrumentos"
BDNS_API_ENDPOINT_REGLAMENTOS = f"{BDNS_API_BASE_URL}/reglamentos"
BDNS_API_ENDPOINT_SECTORES = f"{BDNS_API_BASE_URL}/sectores"
BDNS_API_ENDPOINT_ACTIVIDADES = f"{BDNS_API_BASE_URL}/actividades"
BDNS_API_ENDPOINT_OBJETIVOS = f"{BDNS_API_BASE_URL}/objetivos"
BDNS_API_ENDPOINT_ORGANOS = f"{BDNS_API_BASE_URL}/organos"
BDNS_API_ENDPOINT_ORGANOS_AGRUPACION = f"{BDNS_API_BASE_URL}/organos/agrupacion"
BDNS_API_ENDPOINT_ORGANOS_CODIGO = f"{BDNS_API_BASE_URL}/organos/codigo"
BDNS_API_ENDPOINT_ORGANOS_CODIGO_ADMIN = f"{BDNS_API_BASE_URL}/organos/codigoAdmin"
BDNS_API_ENDPOINT_MICROPORTAL_CONFIGURACION = (
    f"{BDNS_API_BASE_URL}/vpd/{{vpd}}/configuracion"
)
BDNS_API_ENDPOINT_ENLACES = f"{BDNS_API_BASE_URL}/enlaces"
